@@ -1,3 +1,3 @@
 from .throttle import DomainThrottler
-from .status_assigner import StatusAssigner
+from .status_assigner import StatusAssigner, Status
 from .url_validator import URLValidator
\ No newline at end of file
